======================================
Common Validation Patterns for Tendril
======================================

.. image:: https://img.shields.io/travis/chintal/tendril-validation-common.svg
        :target: https://travis-ci.org/chintal/tendril-validation-common

.. image:: https://img.shields.io/pypi/v/tendril-validation-common.svg
        :target: https://pypi.python.org/pypi/tendril-validation-common

* License: AGPLv3
* Documentation: http://tendril-validation-common.readthedocs.org


Common validation patterns for Tendril
